@@ -1,6 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es_ES" sourcelanguage="en_US">
+<!DOCTYPE TS><TS version="2.0" language="es_ES" sourcelanguage="en_US">
 <context>
     <name>Dialog</name>
     <message>
@@ -308,22 +307,22 @@
 <context>
     <name>pyacidobasic</name>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="270"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="269"/>
         <source>File to save</source>
         <translation>Fichero a guardar</translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="270"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="269"/>
         <source>Acidobasic files [*.acb] (*.acb);; All files (*.* *)</source>
         <translation>Ficheros Acidobasic [*.acb] (*.acb);; Cualquier fichero (*.* *)</translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="282"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="281"/>
         <source>Version error</source>
         <translation>Error de versión</translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="294"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="293"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
@@ -363,7 +362,7 @@
         <translation>Un error es posible</translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="282"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="281"/>
         <source>This file is not a valid Pyacidobasic file, version %s.</source>
         <translation>Este archivo, no es un archivo Pyacidobasic válido, de versión %s.</translation>
     </message>
